@@ -11,9 +11,11 @@ broke.
 
 import sys
 
+import elpy
 from elpy.server import ElpyRPCServer
 
 if __name__ == '__main__':
-    sys.stdout.write('elpy-rpc ready\n')
+    sys.stdout.write('elpy-rpc ready ({0})\n'
+                     .format(elpy.__version__))
     sys.stdout.flush()
     ElpyRPCServer().serve_forever()
